// ==============================================
// Copyright 2012 by Chris Valleskey
// Source: chrisvalleskey.com/html5-graph/
// Author: Chris Valleskey
// Do not distribute without authorization.
// ==============================================

var Graph = function(options)
{
	var default_args = {
		
		'interval':	2500,
		'showline':	true,
		'showfill':	true,
		'lineWidth':	2,
		'strokeStyle':	"#666",
		'gridcolor': "#EEE",
		'background': "#F9F9F9",
		'fillStyle':	"rgba(0,0,0,0.25)",
		'showdots':	false,
		'showgrid': true,
		'showlabels': false,

		'call': function(){return Math.floor(Math.random()*100) + 50;}
	}
	for(var index in default_args) {
		if(typeof options[index] == "undefined")
			options[index] = default_args[index];
	}
	
	this.id = options['id'];
	this.interval = options['interval'];
	this.lineWidth = options['lineWidth'];
	this.strokeStyle = options['strokeStyle'];
	this.fillStyle = options['fillStyle'];
	this.gridcolor = options['gridcolor'];
	this.background = options['background'];
	this.showdots = options['showdots'];
	this.showshadow = options['showshadow'];
	this.showgrid = options['showgrid'];
	this.showline = options['showline'];
	this.showfill = options['showfill'];
	this.range = options['range'];
	this.call = options['call'];
	this.data = options['data'];
	this.canvas = document.getElementById(this.id);
	this.context = document.getElementById(this.id).getContext("2d");	
	this.maxvalue = this.range[1] - this.range[0];
	this.scale = Math.round((this.canvas.height / this.maxvalue)*10)/10;
	this.showlabels = options['showlabels'];
	this.labelfilter = options['labelfilter'];
	if(options['grid'].constructor.toString().indexOf("Array") == -1)
	{
		this.grid_x = this.grid_y = Math.floor(options['grid'] * this.scale);
	} else {
		this.grid_x = Math.floor(options['grid'][0] * this.scale);
		this.grid_y = Math.floor(options['grid'][1] * this.scale);
	}
	this.array = [];

	var _self = this;
	
	this.drawGraph = function()
	{
		this.canvas.setAttribute('width',this.canvas.width); // Clear the canvas
		this.context.fillStyle = this.background;
		this.context.fillRect(0,0,this.canvas.width,this.canvas.height); // Fill the background
		
		if(this.showgrid)
			this.drawGrid();
	
		this.context.lineWidth   = this.lineWidth;
		this.context.strokeStyle = this.strokeStyle;
		this.context.fillStyle = this.fillStyle;
		this.context.lineJoin = "round";
		
		if(this.showshadow)
		{
			this.context.shadowColor = this.fillStyle;
			this.context.shadowBlur = 5;
		}

		if(this.array.length > (this.canvas.width/this.grid_x)+1)
			this.array.shift();

		if(this.showfill)
			this.drawFill();
		if(this.showline && this.lineWidth > 0)
			this.drawLine();
		if(this.showdots)
			this.drawDots();
		if(this.showlabels)
			this.drawLabels();
	}		
	this.doGraph = function()
	{	
		call = this.call();
				
		if(call == undefined)
			call = 0;
			
		value = Math.round((this.range[1] - call ) * this.scale);

		this.array.push(value);
		
		if(options['debug'])
			document.getElementById('output').innerHTML = "CALL: " + call + " VALUE: " + value + " SCALE: " + this.scale;

		this.drawGraph();
	}
	this.drawFill = function()
	{
		this.context.beginPath();
		for(var i = 0; i < this.array.length; i++)
		{
			var pos_y = this.array[i];
			
			this.context.lineTo(i*this.grid_x+0.5, pos_y);
		}
			
		this.context.lineTo((i-1)*this.grid_x+0.5, this.canvas.height-0.5);
		this.context.lineTo(0, this.canvas.height);
				
		if(this.array.length > 1)
			this.context.fill();
	
		this.context.closePath();
	}
	this.drawLine = function()
	{
		this.context.beginPath();
		var offset = ((this.context.lineWidth+1)%2)/2;
		for(var i = 0; i < this.array.length; i++)
		{
			var pos_y = this.array[i];
			
			this.context.lineTo(i*this.grid_x+offset, pos_y);
		}
		this.context.stroke();
		this.context.closePath();
	}
	this.drawDots = function()
	{
		this.context.beginPath();
			this.context.fillStyle = this.strokeStyle;
			for(var i = 0; i < this.array.length; i++)
			{			
				var pos_y = this.array[i];
				var dotradius = 3;

				this.context.beginPath();
				this.context.arc(i*this.grid_x+0.5, pos_y-0.5,dotradius,0,Math.PI*2,true);	
				this.context.fill();
				this.context.closePath();
			}		
		this.context.closePath();
	}
	this.drawLabels = function()
	{
			for(var i = 0; i < this.array.length; i++)
			{			
				var pos_y = this.array[i];
				
				if(this.data != undefined)
					text = this.data[i];
				else
					text = Math.round(((this.array[i] / this.scale) - this.range[1]) * -1);

				this.drawLabel(text,i*this.grid_x+0.5, pos_y-0.5);
			}		
	}
	this.drawLabel = function(text,pos_x,pos_y)
	{
		this.context.save();
				
		if(pos_y < 20)
		{
			if(pos_y > 0)
				pos_y += 15;
			else
				pos_y = 13;
		} else if(pos_y > this.canvas.height)
		{
			pos_y = this.canvas.height - 10;
		}
		else
		{
			pos_y -= 10;
		}
		
		if(this.labelfilter != undefined)
			text = this.labelfilter.replace(/%label%/g,text);
		
		this.context.textAlign = "center";
		this.context.font = 'bold 10px/2 sans-serif';
		this.context.fillStyle = "#333";
		this.context.fillText(text,pos_x,pos_y);
		this.context.restore();
	}
	this.drawGrid = function()
	{
		this.context.beginPath();
		if(this.grid_x > 0)
		{
			for (var x = 0.5; x < this.canvas.width; x += this.grid_x)
			{
		  	this.context.moveTo(x, 0);
		  	this.context.lineTo(x, this.canvas.height);
			}
		}
		if(this.grid_y > 0)
		{
			for (var y = this.canvas.height - 0.5; y > 0; y -= this.grid_y)
			{
			  this.context.moveTo(0, y);
			  this.context.lineTo(this.canvas.width, y);
			}
		}
		this.context.strokeStyle = this.gridcolor;
		this.context.stroke();
		this.context.closePath();
	}
	/*this.checkPosition = function(pos_y)
	{
		if(pos_y < 0 )
		{
				pos_y = 0;
		}
		if(pos_y > this.maxvalue * this.scale)
		{
				pos_y = this.maxvalue * this.scale;
		}
		return pos_y;
	}*/
	
	/* Supplemental functions */
	this.toggleValue = function(name)
	{
		this[name] = this[name]? false:true;
		this.drawGraph();
	}
	this.setColor = function(newcolor)
	{
		this.strokeStyle = newcolor;
		this.drawGraph();
	}
	this.setFill = function(newfill)
	{
			
		this.fillStyle = newfill;
		this.drawGraph();
	}
	this.setValue = function(name,value)
	{
		this[name] = value;
		this.drawGraph();
	}
	this.toggleDraw = function()
	{
		if(this.timer == undefined)
		{
			this.timer = setInterval(draw, this.interval);
		}
		else
		{
			clearInterval(this.timer);
			this.timer = undefined;
		}
	}
	this.clearGraph = function()
	{
		this.array = [];
		this.drawGraph();
	}
	
	function draw()
	{
		_self.doGraph();
	}

	// If this is a dynamic graph, begin the timer, otherwise draw the graph
	if(this.data == undefined)
	{
		this.timer = setInterval(draw, this.interval);
		this.doGraph();
	}
	else
	{
		for(var i =0; i < this.data.length; i++)
		{
			this.array[i] = Math.round((this.range[1] - this.data[i] ) * this.scale); // Convert real values to graph values
		}	
		this.drawGraph();
	}
}




 function getXmlHttpRequestObject() {
	 if (window.XMLHttpRequest) {
		 return new XMLHttpRequest();
	 } else if (window.ActiveXObject) {
		 return new ActiveXObject("Microsoft.XMLHTTP");
	 } else {
		 alert("Your Browser does not support AJAX!\nIt's about time to upgrade don't you think?");
	 }
 }

 //XmlHttpRequest object
 var req = getXmlHttpRequestObject();
 var htmlTarget;
 var timer = 0;

 function getRequest(resource, elementId) {
 	
	// handle the case where a querystring is not detected
	var char = "&";
 	if(resource.indexOf("?", 0) == -1) {
		char = "?";
	}
		
	 if (req.readyState == 4 || req.readyState == 0) {
		 req.open("GET", resource + char + 'ms=' + new Date().getTime(), true);
		 req.onreadystatechange = handleResponse;
		 htmlTarget = elementId;
		 req.send(null);
		 return false;
	 }
 }

function handleResponse() {
	
	 if (req.readyState == 4) {
		 timer = 0;
		parseState(req.responseXML);
	 }
	 /*
	 if(req.readState == 1 || req.readyState == 3){
		timer++;		 
	 }
	 
	 if(timer == 2000)
	 	parseState(null);
		*/
} 

function parseState(xDoc) {
	if(xDoc == null)
		return
		
	var target = document.getElementById("placeholder");
	target.innerHTML = xDoc.getElementsByTagName("temp")[0].childNodes[0].nodeValue;
	
	var target = document.getElementById("placeholder2");
	target.innerHTML = xDoc.getElementsByTagName("humidity")[0].childNodes[0].nodeValue;

	var target = document.getElementById("tmax");
	target.innerHTML = xDoc.getElementsByTagName("tmax")[0].childNodes[0].nodeValue;

	var target = document.getElementById("tmin");
	target.innerHTML = xDoc.getElementsByTagName("tmin")[0].childNodes[0].nodeValue;

	var target = document.getElementById("lvmax");
	target.innerHTML = xDoc.getElementsByTagName("lvmax")[0].childNodes[0].nodeValue;

	var target = document.getElementById("lvmin");
	target.innerHTML = xDoc.getElementsByTagName("lvmin")[0].childNodes[0].nodeValue;
	
	var target = document.getElementById("setpoint_1");
	target.innerHTML = xDoc.getElementsByTagName("setpoint_1")[0].childNodes[0].nodeValue;

	var target = document.getElementById("offset_1");
	target.innerHTML = xDoc.getElementsByTagName("offset_1")[0].childNodes[0].nodeValue;
	
	var target = document.getElementById("function_1");
	target.innerHTML = xDoc.getElementsByTagName("function_1")[0].childNodes[0].nodeValue;
	
	var target = document.getElementById("status_1");
	target.innerHTML = xDoc.getElementsByTagName("status_1")[0].childNodes[0].nodeValue;

	var target = document.getElementById("setpoint_2");
	target.innerHTML = xDoc.getElementsByTagName("setpoint_2")[0].childNodes[0].nodeValue;

	var target = document.getElementById("offset_2");
	target.innerHTML = xDoc.getElementsByTagName("offset_2")[0].childNodes[0].nodeValue;
	
	var target = document.getElementById("function_2");
	target.innerHTML = xDoc.getElementsByTagName("function_2")[0].childNodes[0].nodeValue;
	
	var target = document.getElementById("status_2");
	target.innerHTML = xDoc.getElementsByTagName("status_2")[0].childNodes[0].nodeValue;
	

}

function latestTemp(){	
	var temp = document.getElementById("placeholder").innerHTML
	return parseInt(temp);	
}

function latestHumidity() {
	var temp = document.getElementById("placeholder2").innerHTML
	return parseInt(temp);
}

function setpoint_1plus()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","setpoint_1plus-proxy",true);
xmlhttp.send();
}

function setpoint_1min()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","setpoint_1min-proxy",true);
xmlhttp.send();
}

function offset_1plus()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","offset_1plus-proxy",true);
xmlhttp.send();
}

function offset_1min()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","offset_1min-proxy",true);
xmlhttp.send();
}

function setpoint_1Var()
{
var x;

var name=prompt("Set Manual setpoint_1(1-99)","setpoint_1");

if (name!=null)
  {
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("POST","setvar"+ name,true);
xmlhttp.send();
}
}



function setpoint_2plus()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","setpoint_2plus-proxy",true);
xmlhttp.send();
}

function setpoint_2min()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","setpoint_2min-proxy",true);
xmlhttp.send();
}

function offset_2plus()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","offset_2plus-proxy",true);
xmlhttp.send();
}

function offset_2min()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","offset_2min-proxy",true);
xmlhttp.send();
}

function setpoint_1Var()
{
var x;

var name=prompt("Set Manual setpoint_1(1-99)","setpoint_1");

if (name!=null)
  {
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","setvar"+ name,true);
xmlhttp.send();
}
}




function offset_1Var()
{
var x;

var name=prompt("Set Manual offset_1(1-10)","offset_1");

if (name!=null)
  {
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","offset_1var"+ name,true);
xmlhttp.send();
}
}

function funtion_to_1()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","funtion_1_1-proxy",true);
xmlhttp.send();
}

function funtion_to_2()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","funtion_1_2-proxy",true);
xmlhttp.send();
}

function funtion_to_3()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","funtion_1_3-proxy",true);
xmlhttp.send();
}
function funtion_to_4()
{
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","funtion_1_4-proxy",true);
xmlhttp.send();
}
;

function setting_display1()


{

var s = document.getElementById("function_1").innerHTML

if (s == 01)
{
document.getElementById("nameplate1").innerHTML="Kachel";
};

if (s == 02)
{
document.getElementById("nameplate1").innerHTML="Koeler";
};

if (s == 03)
{
document.getElementById("nameplate1").innerHTML="Bevochtiger";
};

if (s == 04)
{
document.getElementById("nameplate1").innerHTML="Ontvochtiger";
};

};

function setting_display2()


{

var s = document.getElementById("function_2").innerHTML

if (s == 01)
{
document.getElementById("nameplate2").innerHTML="Kachel";
};

if (s == 02)
{
document.getElementById("nameplate2").innerHTML="Koeler";
};

if (s == 03)
{
document.getElementById("nameplate2").innerHTML="Bevochtiger";
};

if (s == 04)
{
document.getElementById("nameplate2").innerHTML="Ontvochtiger";
};

};

function setupsend()
{

var x;
var oForm = document.forms["setup"]
var oTagsList = oForm.elements["functie"];
var value = oTagsList.value;

var oTagsList = oForm.elements["px"];
var pxx = oTagsList.value;

if (name!=null)
  {
var xmlhttp;
if (window.XMLHttpRequest)
  {// code for IE7+, Firefox, Chrome, Opera, Safari
  xmlhttp=new XMLHttpRequest();
  }
else
  {// code for IE6, IE5
  xmlhttp=new ActiveXObject("Microsoft.XMLHTTP");
  }

xmlhttp.open("GET","funtion_" + pxx +  "_"+ value + "-proxy",true);
xmlhttp.send();
}
}

function touchStart( e ) {
var box = document.getElementById("box");
box.style.background = "green";
e.preventDefault();
return false;
}


